/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GTK_COMPASS_H__
#define __GTK_COMPASS_H__


#include <gdk/gdk.h>
#include <gtk/gtkadjustment.h>
#include <gtk/gtkwidget.h>


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define GTK_COMPASS(obj)          GTK_CHECK_CAST (obj, gtk_compass_get_type (), GtkCompass)
#define GTK_COMPASS_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gtk_compass_get_type (), GtkCompassClass)
#define GTK_IS_COMPASS(obj)       GTK_CHECK_TYPE (obj, gtk_compass_get_type ())

#define DEGREES(rad)	((rad)/M_PI * 180.0)+180
#define RADIANS(deg)	((deg)/180.0 * M_PI)

typedef struct _GtkCompass        GtkCompass;
typedef struct _GtkCompassClass   GtkCompassClass;

struct _GtkCompass
{
  GtkWidget widget;

  /* update policy (GTK_UPDATE_[CONTINUOUS/DELAYED/DISCONTINUOUS]) */
  guint policy : 2;

  /* Button currently pressed or 0 if none */
  guint8 button;

  /* Dimensions of compass components */
  gint radius;
  gint pointer_width;

  /* ID of update timer, or 0 if none */
  guint32 timer;

  /* Current angle */
  gfloat angle;
  gfloat last_angle;

  /* Old values from adjustment stored so we know when something changes */
  gfloat old_value;
  gfloat old_lower;
  gfloat old_upper;

  /* The adjustment object that stores the data for this compass */
  GtkAdjustment *adjustment;
 /* The pixel image of the compass rose if there is one */
  GtkWidget *compassRosePix;
};

struct _GtkCompassClass
{
  GtkWidgetClass parent_class;
};


GtkWidget*     gtk_compass_new                    (GtkAdjustment *adjustment);
GtkType        gtk_compass_get_type               (void);
GtkAdjustment* gtk_compass_get_adjustment         (GtkCompass      *compass);
void           gtk_compass_set_update_policy      (GtkCompass      *compass,
						GtkUpdateType  policy);

void           gtk_compass_set_adjustment         (GtkCompass      *compass,
						GtkAdjustment *adjustment);
#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GTK_COMPASS_H__ */

